@@ -54,8 +54,9 @@ fsal_status_t GPFSFSAL_rename(struct fsal_obj_handle *old_hdl,
 	fsal_status_t status;
 	struct stat buffstat;
 	struct gpfs_fsal_obj_handle *old_gpfs_hdl, *new_gpfs_hdl;
-	struct gpfs_fsal_export *exp = container_of(
-		op_ctx->fsal_export, struct gpfs_fsal_export, export);
+	struct gpfs_fsal_export *exp = container_of(op_ctx->fsal_export,
+						    struct gpfs_fsal_export,
+						    export);
 	int export_fd = exp->export_fd;
 
 	old_gpfs_hdl =
