@@ -312,14 +312,16 @@ out_unref:
  * @return FSAL status.
  */
 
-fsal_status_t
-mdcache_open2(struct fsal_obj_handle *obj_hdl, struct state_t *state,
-	      fsal_openflags_t openflags, enum fsal_create_mode createmode,
-	      const char *name, struct fsal_attrlist *attrs_in,
-	      fsal_verifier_t verifier, struct fsal_obj_handle **new_obj,
-	      struct fsal_attrlist *attrs_out, bool *caller_perm_check,
-	      struct fsal_attrlist *parent_pre_attrs_out,
-	      struct fsal_attrlist *parent_post_attrs_out)
+fsal_status_t mdcache_open2(struct fsal_obj_handle *obj_hdl,
+			    struct state_t *state, fsal_openflags_t openflags,
+			    enum fsal_create_mode createmode, const char *name,
+			    struct fsal_attrlist *attrs_in,
+			    fsal_verifier_t verifier,
+			    struct fsal_obj_handle **new_obj,
+			    struct fsal_attrlist *attrs_out,
+			    bool *caller_perm_check,
+			    struct fsal_attrlist *parent_pre_attrs_out,
+			    struct fsal_attrlist *parent_post_attrs_out)
 {
 	mdcache_entry_t *mdc_parent =
 		container_of(obj_hdl, mdcache_entry_t, obj_handle);
