@@ -114,7 +114,8 @@ fsal_status_t mdcache_alloc_and_check_handle(
 					   MDCACHE_TRUST_ATTRS);
 	}
 
-	if (mdcache_param.dir.avl_chunk != 0) {
+	if ((mdcache_param.dir.avl_chunk != 0) &&
+	    (!op_ctx_export_has_option(EXPORT_OPTION_NO_DIR_CACHING))) {
 		/* Add this entry to the directory (also takes an internal ref)
 		 */
 		status =
@@ -508,7 +509,8 @@ static fsal_status_t mdcache_link(struct fsal_obj_handle *obj_hdl,
 		return status;
 	}
 
-	if (mdcache_param.dir.avl_chunk != 0) {
+	if ((mdcache_param.dir.avl_chunk != 0) &&
+	    (!op_ctx_export_has_option(EXPORT_OPTION_NO_DIR_CACHING))) {
 		PTHREAD_RWLOCK_wrlock(&dest->content_lock);
 
 		/* Add this entry to the directory (also takes an internal ref)
@@ -559,7 +561,8 @@ static fsal_status_t mdcache_readdir(struct fsal_obj_handle *dir_hdl,
 	if (!(directory->obj_handle.type == DIRECTORY))
 		return fsalstat(ERR_FSAL_NOTDIR, 0);
 
-	if (mdcache_param.dir.avl_chunk == 0) {
+	if ((mdcache_param.dir.avl_chunk == 0) ||
+	    (op_ctx_export_has_option(EXPORT_OPTION_NO_DIR_CACHING))) {
 		/* Not caching dirents; pass through directly to FSAL */
 		return mdcache_readdir_uncached(directory, whence, dir_state,
 						cb, attrmask, eod_met);
@@ -752,7 +755,8 @@ static fsal_status_t mdcache_rename(struct fsal_obj_handle *obj_hdl,
 		/* Handle key is changing.  This means the old handle is
 		 * useless.  Mark it unreachable, forcing a lookup next time */
 		mdc_unreachable(mdc_obj);
-	} else if (mdcache_param.dir.avl_chunk != 0) {
+	} else if ((mdcache_param.dir.avl_chunk != 0) &&
+		   (!op_ctx_export_has_option(EXPORT_OPTION_NO_DIR_CACHING))) {
 		bool invalidate = true;
 
 		LogDebug(COMPONENT_MDCACHE,
