@@ -277,6 +277,18 @@ static void fsal_reset_stats(struct fsal_module *const fsal_hdl)
 	LogDebug(COMPONENT_FSAL, "Invoking unsupported FSAL operation");
 }
 
+/**
+ * @brief FSAL function to reclaim the client capabilities
+ *
+ * @param[in] fsal_hdl          FSAL module
+ */
+static fsal_status_t fsal_reclaim_client(struct fsal_module *const fsal_hdl,
+					 char *nodeid)
+{
+	LogDebug(COMPONENT_FSAL, "Invoking unsupported FSAL operation");
+	return fsalstat(ERR_FSAL_NOTSUPP, ENOTSUP);
+}
+
 /* Default fsal module method vector.
  * copied to allocated vector at register time
  */
@@ -295,6 +307,7 @@ struct fsal_ops def_fsal_ops = {
 	.fsal_pnfs_ds_ops = fsal_pnfs_ds_ops,
 	.fsal_extract_stats = fsal_extract_stats,
 	.fsal_reset_stats = fsal_reset_stats,
+	.fsal_reclaim_client = fsal_reclaim_client,
 };
 
 /* get_name
@@ -976,13 +989,15 @@ static fsal_status_t linkfile(struct fsal_obj_handle *obj_hdl,
  * default case not supported
  */
 
-static fsal_status_t
-renamefile(struct fsal_obj_handle *obj_hdl, struct fsal_obj_handle *olddir_hdl,
-	   const char *old_name, struct fsal_obj_handle *newdir_hdl,
-	   const char *new_name, struct fsal_attrlist *olddir_pre_attrs_out,
-	   struct fsal_attrlist *olddir_post_attrs_out,
-	   struct fsal_attrlist *newdir_pre_attrs_out,
-	   struct fsal_attrlist *newdir_post_attrs_out)
+static fsal_status_t renamefile(struct fsal_obj_handle *obj_hdl,
+				struct fsal_obj_handle *olddir_hdl,
+				const char *old_name,
+				struct fsal_obj_handle *newdir_hdl,
+				const char *new_name,
+				struct fsal_attrlist *olddir_pre_attrs_out,
+				struct fsal_attrlist *olddir_post_attrs_out,
+				struct fsal_attrlist *newdir_pre_attrs_out,
+				struct fsal_attrlist *newdir_post_attrs_out)
 {
 	LogCrit(COMPONENT_FSAL, "Invoking unsupported FSAL operation");
 	return fsalstat(ERR_FSAL_NOTSUPP, ENOTSUP);
@@ -1040,10 +1055,12 @@ static fsal_status_t file_fallocate(struct fsal_obj_handle *obj_hdl,
  * default case not supported
  */
 
-static fsal_status_t
-list_ext_attrs(struct fsal_obj_handle *obj_hdl, unsigned int cookie,
-	       fsal_xattrent_t *xattrs_tab, unsigned int xattrs_tabsize,
-	       unsigned int *p_nb_returned, int *end_of_list)
+static fsal_status_t list_ext_attrs(struct fsal_obj_handle *obj_hdl,
+				    unsigned int cookie,
+				    fsal_xattrent_t *xattrs_tab,
+				    unsigned int xattrs_tabsize,
+				    unsigned int *p_nb_returned,
+				    int *end_of_list)
 {
 	LogCrit(COMPONENT_FSAL, "Invoking unsupported FSAL operation");
 	return fsalstat(ERR_FSAL_NOTSUPP, ENOTSUP);
@@ -1243,14 +1260,16 @@ static nfsstat4 layoutcommit(struct fsal_obj_handle *obj_hdl, XDR *lou_body,
  * default case not supported
  */
 
-static fsal_status_t
-open2(struct fsal_obj_handle *obj_hdl, struct state_t *fd,
-      fsal_openflags_t openflags, enum fsal_create_mode createmode,
-      const char *name, struct fsal_attrlist *attrib_set,
-      fsal_verifier_t verifier, struct fsal_obj_handle **new_obj,
-      struct fsal_attrlist *attrs_out, bool *caller_perm_check,
-      struct fsal_attrlist *parent_pre_attrs_out,
-      struct fsal_attrlist *parent_post_attrs_out)
+static fsal_status_t open2(struct fsal_obj_handle *objectHandle,
+			   struct state_t *state, fsal_openflags_t openflags,
+			   enum fsal_create_mode createmode, const char *name,
+			   struct fsal_attrlist *attributesToSet,
+			   fsal_verifier_t verifier,
+			   struct fsal_obj_handle **createdObject,
+			   struct fsal_attrlist *attributes,
+			   bool *callerPermissionCheck,
+			   struct fsal_attrlist *parentPreAttributes,
+			   struct fsal_attrlist *parentPostAttributes)
 {
 	LogCrit(COMPONENT_FSAL, "Invoking unsupported FSAL operation");
 	return fsalstat(ERR_FSAL_NOTSUPP, ENOTSUP);
@@ -1612,11 +1631,13 @@ static nfsstat4 ds_read_plus(struct fsal_ds_handle *const ds_hdl,
  *
  * @return An NFSv4.1 status code.
  */
-static nfsstat4
-ds_write(struct fsal_ds_handle *const ds_hdl, const stateid4 *stateid,
-	 const offset4 offset, const count4 write_length, const void *buffer,
-	 const stable_how4 stability_wanted, count4 *const written_length,
-	 verifier4 *const writeverf, stable_how4 *const stability_got)
+static nfsstat4 ds_write(struct fsal_ds_handle *const ds_hdl,
+			 const stateid4 *stateid, const offset4 offset,
+			 const count4 write_length, const void *buffer,
+			 const stable_how4 stability_wanted,
+			 count4 *const written_length,
+			 verifier4 *const writeverf,
+			 stable_how4 *const stability_got)
 {
 	LogCrit(COMPONENT_PNFS, "Unimplemented DS write!");
 	return NFS4ERR_NOTSUPP;
