@@ -657,6 +657,7 @@ typedef enum enum_fsal_fsinfo_options {
 	fso_compliant_eof_behavior,
 	fso_xattr_support,
 	fso_allocate_own_read_buffer,
+	fso_preserve_unlinked,
 } fsal_fsinfo_options_t;
 
 /* The largest maxread and maxwrite value */
@@ -723,6 +724,7 @@ typedef struct fsal_staticfsinfo_t {
 				       change for a directory with an upcall,
 				       set this to -1. Else set it to some
 				       positive value. Defaults to -1. */
+	bool preserve_unlinked; /*< FSAL preserves unlinked files */
 } fsal_staticfsinfo_t;
 
 /**
@@ -965,18 +967,23 @@ struct fsal_fd {
 /* FSAL_FD_TEMP initializer, the work_mutex, io_work_cond, and fd_work_cond are
  * not initialized as these are never used with a FSAL_FD_TEMP.
  */
-#define FSAL_FD_INIT                                                                            \
-	{ .openflags = FSAL_O_CLOSED,                                                           \
-	  .fd_work = 0,                                                                         \
-	  .io_work = 0,                                                                         \
-	  .want_read = 0,                                                                       \
-	  .want_write = 0,                                                                      \
-	  .fsal_export = op_ctx->fsal_export,                                                   \
-	  .fd_lru = { NULL, NULL }, /* work_mutex unused for FSAL_FD_TEMP */                    \
-	  /* io_work_cond unused for FSAL_FD_TEMP */ /* fd_work_cond unused for FSAL_FD_TEMP */ \
-	  .close_on_complete = false,                                                           \
-	  .lru_reclaim = 0,                                                                     \
-	  .fd_type = FSAL_FD_TEMP }
+/* clang-format off */
+#define FSAL_FD_INIT                                        \
+	{                                                   \
+		.openflags = FSAL_O_CLOSED,                 \
+		.fd_work = 0,                               \
+		.io_work = 0,                               \
+		.want_read = 0,                             \
+		.want_write = 0,                            \
+		.fsal_export = op_ctx->fsal_export,         \
+		.fd_lru = { NULL, NULL },                   \
+		/* work_mutex unused for FSAL_FD_TEMP */    \
+		/* io_work_cond unused for FSAL_FD_TEMP */  \
+		/* fd_work_cond unused for FSAL_FD_TEMP */  \
+		.close_on_complete = false,                 \
+		.lru_reclaim = 0, .fd_type = FSAL_FD_TEMP   \
+	}
+/* clang-format on */
 
 static inline void init_fsal_fd(struct fsal_fd *fsal_fd,
 				enum fsal_fd_type fd_type,
