@@ -54,6 +54,11 @@
 #include "config.h"
 #include "gsh_types.h"
 #include "monitoring.h"
+
+#ifdef HAVE_PROCPS
+#include <proc/readproc.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -94,6 +99,10 @@ void dynamic_metrics__mdcache_cache_hit(const char *operation,
 void dynamic_metrics__mdcache_cache_miss(const char *operation,
 					 export_id_t export_id);
 
+#ifdef HAVE_PROCPS
+void dynamic_metrics__mem_info(proc_t proc_info);
+#endif
+
 #else /* USE_MONITORING */
 
 #ifndef UNUSED
@@ -117,7 +126,7 @@ static inline void dynamic_metrics__observe_nfs_request(
 static inline void dynamic_metrics__observe_nfs_io(
 	size_t UNUSED(bytes_requested), size_t UNUSED(bytes_transferred),
 	bool UNUSED(is_write), export_id_t UNUSED(export_id),
-	const char *UNUSED(client_ip))
+	const char *UNUSED(path), const char *UNUSED(client_ip))
 {
 }
 
@@ -130,6 +139,9 @@ static inline void dynamic_metrics__mdcache_cache_miss(
 	const char *UNUSED(operation), export_id_t UNUSED(export_id))
 {
 }
+static inline void dynamic_metrics__mem_info(proc_t *UNUSED(proc_info))
+{
+}
 
 #endif /* USE_MONITORING */
 
